@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-02'; # DATE
+our $DATE = '2023-08-06'; # DATE
 our $DIST = 'App-TrashUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our %SPEC;
 
@@ -17,11 +17,18 @@ sub _complete_trashed_filenames {
     require File::Trash::FreeDesktop;
 
     my %args = @_;
+    my $word = $args{word} // '';
 
     my $trash = File::Trash::FreeDesktop->new;
     my @ct = $trash->list_contents;
 
-    Complete::Util::complete_array_elem(array=>[map { my $filename = $_->{path}; $filename =~ s!.+/!!; $filename } @ct], word=>$args{word});
+    if ($word =~ m!/!) {
+        # if word contains '/', then we complete with trashed files' paths
+        Complete::Util::complete_array_elem(array=>[map { $_->{path} } @ct], word=>$word);
+    } else {
+        # otherwise we complete with trashed files' filenames
+        Complete::Util::complete_array_elem(array=>[map { my $filename = $_->{path}; $filename =~ s!.+/!!; $filename } @ct], word=>$word);
+    }
 }
 
 $SPEC{trash_list} = {
@@ -328,7 +335,7 @@ App::TrashUtils - Utilities related to desktop trash
 
 =head1 VERSION
 
-This document describes version 0.002 of App::TrashUtils (from Perl distribution App-TrashUtils), released on 2023-08-02.
+This document describes version 0.003 of App::TrashUtils (from Perl distribution App-TrashUtils), released on 2023-08-06.
 
 =head1 DESCRIPTION
 
